aboutsummaryrefslogtreecommitdiff
path: root/build2/version/snapshot-git.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'build2/version/snapshot-git.cxx')
-rw-r--r--build2/version/snapshot-git.cxx2
1 files changed, 1 insertions, 1 deletions
diff --git a/build2/version/snapshot-git.cxx b/build2/version/snapshot-git.cxx
index 9dd50c5..b85b47e 100644
--- a/build2/version/snapshot-git.cxx
+++ b/build2/version/snapshot-git.cxx
@@ -137,7 +137,7 @@ namespace build2
cs.append ("commit " + to_string (data.size ())); // Includes '\0'.
cs.append (data.c_str (), data.size ());
- r.id.assign (cs.string (), 16); // 16-characters abbreviated commit id.
+ r.id.assign (cs.string (), 12); // 12-characters abbreviated commit id.
return r;
}